@@ -37,7 +37,9 @@ def convert_to_xml(
 
     merge_validation(result)
     clean_extractor(result)
-    clean_validation(result["validation"])
+
+    if validation_endpoint:
+        clean_validation(result["validation"])
 
     # One of the dirties hack I've ever done, here. I'm sorry
     if tax_rate_as_percentage:
@@ -136,7 +138,7 @@ def merge_validation(result):
                     else "low",
                     "#text": "{:.2f}".format(value)
                     if entity in AMOUNT_FIELDS
-                    else str(value),
+                    else escape_special_chars(str(value)),
                 }
 
     if "validation" in result:
@@ -144,7 +146,7 @@ def merge_validation(result):
             result["invoiceExtractor"]["entities"], return_dict, result["validation"]
         )
     else:
-        traverse_merge_items(result["invoiceExtractor"]["entities"], return_dict)
+        traverse_merge_items(result["invoiceExtractor"]["entities"], return_dict, None)
 
     result["invoiceExtractor"]["entities"] = return_dict
 
@@ -197,6 +199,24 @@ def clean_validation(validation):
             del validation["totals"][0]["tax"]
 
 
+def escape_special_chars(value):
+    """The xml format has 5 special characters which need to be escaped/replaced.
+
+    Arguments:
+        value {[type]} -- Value of a Field
+
+    Returns:
+        [type] -- Field value with the 5 special characters escaped.
+    """
+    special_chars = {"&": "&amp", ">": "&gt", "<": "&lt", "'": "&apos", '"': "&quot"}
+
+    for char, replace_char in special_chars.items():
+        if char in value:
+            value = value.replace(char, replace_char)
+
+    return value
+
+
 def create_risk(entity, validation_errors):
     """ Create risk flag """
     err_amount = len(validation_errors)
